# Copyright (C) 2009, 2010, 2013, 2014 Nicira Networks, Inc.
#
# Copying and distribution of this file, with or without modification,
# are permitted in any medium without royalty provided the copyright
# notice and this notice are preserved.  This file is offered as-is,
# without warranty of any kind.
#
# If tests have to be skipped while building, specify the '--without check'
# option. For example:
# rpmbuild -bb --without check rhel/openvswitch-fedora.spec

# This defines the base package name's version.

%define pkgver 2.13
%define pkgname ovn22.12

# If libcap-ng isn't available and there is no need for running OVS
# as regular user, specify the '--without libcapng'
%bcond_without libcapng

# Enable PIE, bz#955181
%global _hardened_build 1

# RHEL-7 doesn't define _rundir macro yet
# Fedora 15 onwards uses /run as _rundir
%if 0%{!?_rundir:1}
%define _rundir /run
%endif

# Build python2 (that provides python) and python3 subpackages on Fedora
# Build only python3 (that provides python) subpackage on RHEL8
# Build only python subpackage on RHEL7
%if 0%{?rhel} > 7 || 0%{?fedora}
# On RHEL8 Sphinx is included in buildroot
%global external_sphinx 1
%else
# Don't use external sphinx (RHV doesn't have optional repositories enabled)
%global external_sphinx 0
%endif

# We would see rpmlinit error - E: hardcoded-library-path in '% {_prefix}/lib'.
# But there is no solution to fix this. Using {_lib} macro will solve the
# rpmlink error, but will install the files in /usr/lib64/.
# OVN pacemaker ocf script file is copied in /usr/lib/ocf/resource.d/ovn/
# and we are not sure if pacemaker looks into this path to find the
# OVN resource agent script.
%global ovnlibdir %{_prefix}/lib

Name: %{pkgname}
Summary: Open Virtual Network support
Group: System Environment/Daemons
URL: http://www.ovn.org/
Version: 22.12.0
Release: 108%{?commit0:.%{date}git%{shortcommit0}}%{?dist}
Provides: openvswitch%{pkgver}-ovn-common = %{?epoch:%{epoch}:}%{version}-%{release}
Obsoletes: openvswitch%{pkgver}-ovn-common < 2.11.0-1

# Nearly all of openvswitch is ASL 2.0.  The bugtool is LGPLv2+, and the
# lib/sflow*.[ch] files are SISSL
License: ASL 2.0 and LGPLv2+ and SISSL

# Always pull an upstream release, since this is what we rebase to.
Source: https://github.com/ovn-org/ovn/archive/v%{version}.tar.gz#/ovn-%{version}.tar.gz

%define ovscommit a787fbbf9dd6a108a53053afb45fb59a0b58b514
%define ovsshortcommit a787fbb

Source10: https://github.com/openvswitch/ovs/archive/%{ovscommit}.tar.gz#/openvswitch-%{ovsshortcommit}.tar.gz
%define ovsdir ovs-%{ovscommit}

%define docutilsver 0.12
%define pygmentsver 1.4
%define sphinxver   1.1.3
Source100: https://pypi.io/packages/source/d/docutils/docutils-%{docutilsver}.tar.gz
Source101: https://pypi.io/packages/source/P/Pygments/Pygments-%{pygmentsver}.tar.gz
Source102: https://pypi.io/packages/source/S/Sphinx/Sphinx-%{sphinxver}.tar.gz

Source500: configlib.sh
Source501: gen_config_group.sh
Source502: set_config.sh

# Important: source503 is used as the actual copy file
# @TODO: this causes a warning - fix it?
Source504: arm64-armv8a-linuxapp-gcc-config
Source505: ppc_64-power8-linuxapp-gcc-config
Source506: x86_64-native-linuxapp-gcc-config

Patch:     %{pkgname}.patch

# FIXME Sphinx is used to generate some manpages, unfortunately, on RHEL, it's
# in the -optional repository and so we can't require it directly since RHV
# doesn't have the -optional repository enabled and so TPS fails
%if %{external_sphinx}
BuildRequires: python3-sphinx
%else
# Sphinx dependencies
BuildRequires: python-devel
BuildRequires: python-setuptools
#BuildRequires: python2-docutils
BuildRequires: python-jinja2
BuildRequires: python-nose
#BuildRequires: python2-pygments
# docutils dependencies
BuildRequires: python-imaging
# pygments dependencies
BuildRequires: python-nose
%endif

BuildRequires: gcc gcc-c++ make
BuildRequires: autoconf automake libtool
BuildRequires: systemd-units openssl openssl-devel
BuildRequires: python3-devel python3-setuptools
BuildRequires: desktop-file-utils
BuildRequires: groff-base graphviz
BuildRequires: unbound-devel

# make check dependencies
BuildRequires: procps-ng
%if 0%{?rhel} == 8 || 0%{?fedora}
BuildRequires: python3-pyOpenSSL
%endif
BuildRequires: tcpdump

%if %{with libcapng}
BuildRequires: libcap-ng libcap-ng-devel
%endif

Requires: hostname openssl iproute module-init-tools

Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units

# to skip running checks, pass --without check
%bcond_without check

%description
OVN, the Open Virtual Network, is a system to support virtual network
abstraction.  OVN complements the existing capabilities of OVS to add
native support for virtual network abstractions, such as virtual L2 and L3
overlays and security groups.

%package central
Summary: Open Virtual Network support
License: ASL 2.0
Requires: %{pkgname}
Requires: firewalld-filesystem
Provides: openvswitch%{pkgver}-ovn-central = %{?epoch:%{epoch}:}%{version}-%{release}
Obsoletes: openvswitch%{pkgver}-ovn-central < 2.11.0-1

%description central
OVN DB servers and ovn-northd running on a central node.

%package host
Summary: Open Virtual Network support
License: ASL 2.0
Requires: %{pkgname}
Requires: firewalld-filesystem
Provides: openvswitch%{pkgver}-ovn-host = %{?epoch:%{epoch}:}%{version}-%{release}
Obsoletes: openvswitch%{pkgver}-ovn-host < 2.11.0-1

%description host
OVN controller running on each host.

%package vtep
Summary: Open Virtual Network support
License: ASL 2.0
Requires: %{pkgname}
Provides: openvswitch%{pkgver}-ovn-vtep = %{?epoch:%{epoch}:}%{version}-%{release}
Obsoletes: openvswitch%{pkgver}-ovn-vtep < 2.11.0-1

%description vtep
OVN vtep controller

%prep
%autosetup -n ovn-%{version} -a 10 -p 1

%build
%if 0%{?commit0:1}
# fix the snapshot unreleased version to be the released one.
sed -i.old -e "s/^AC_INIT(openvswitch,.*,/AC_INIT(openvswitch, %{version},/" configure.ac
%endif
./boot.sh

# OVN source code is now separate.
# Build openvswitch first.
# XXX Current openvswitch2.13 doesn't
# use "2.13.0" for version. It's a commit hash
pushd %{ovsdir}
./boot.sh
%configure \
%if %{with libcapng}
        --enable-libcapng \
%else
        --disable-libcapng \
%endif
        --enable-ssl \
        --with-pkidir=%{_sharedstatedir}/openvswitch/pki

make %{?_smp_mflags}
popd

# Build OVN.
# XXX OVS version needs to be updated when ovs2.13 is updated.
%configure \
        --with-ovs-source=$PWD/%{ovsdir} \
%if %{with libcapng}
        --enable-libcapng \
%else
        --disable-libcapng \
%endif
        --enable-ssl \
        --with-pkidir=%{_sharedstatedir}/openvswitch/pki

make %{?_smp_mflags}

%install
%make_install
install -p -D -m 0644 \
        rhel/usr_share_ovn_scripts_systemd_sysconfig.template \
        $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/ovn

for service in ovn-controller ovn-controller-vtep ovn-northd; do
        install -p -D -m 0644 \
                        rhel/usr_lib_systemd_system_${service}.service \
                        $RPM_BUILD_ROOT%{_unitdir}/${service}.service
done

install -d -m 0755 $RPM_BUILD_ROOT/%{_sharedstatedir}/ovn

install -d $RPM_BUILD_ROOT%{ovnlibdir}/firewalld/services/
install -p -m 0644 rhel/usr_lib_firewalld_services_ovn-central-firewall-service.xml \
        $RPM_BUILD_ROOT%{ovnlibdir}/firewalld/services/ovn-central-firewall-service.xml
install -p -m 0644 rhel/usr_lib_firewalld_services_ovn-host-firewall-service.xml \
        $RPM_BUILD_ROOT%{ovnlibdir}/firewalld/services/ovn-host-firewall-service.xml

install -d -m 0755 $RPM_BUILD_ROOT%{ovnlibdir}/ocf/resource.d/ovn
ln -s %{_datadir}/ovn/scripts/ovndb-servers.ocf \
      $RPM_BUILD_ROOT%{ovnlibdir}/ocf/resource.d/ovn/ovndb-servers

install -p -D -m 0644 rhel/etc_logrotate.d_ovn \
        $RPM_BUILD_ROOT/%{_sysconfdir}/logrotate.d/ovn

# remove unneeded files.
rm -f $RPM_BUILD_ROOT%{_bindir}/ovs*
rm -f $RPM_BUILD_ROOT%{_bindir}/vtep-ctl
rm -f $RPM_BUILD_ROOT%{_sbindir}/ovs*
rm -f $RPM_BUILD_ROOT%{_mandir}/man1/ovs*
rm -f $RPM_BUILD_ROOT%{_mandir}/man5/ovs*
rm -f $RPM_BUILD_ROOT%{_mandir}/man5/vtep*
rm -f $RPM_BUILD_ROOT%{_mandir}/man7/ovs*
rm -f $RPM_BUILD_ROOT%{_mandir}/man8/ovs*
rm -f $RPM_BUILD_ROOT%{_mandir}/man8/vtep*
rm -rf $RPM_BUILD_ROOT%{_datadir}/ovn/python
rm -f $RPM_BUILD_ROOT%{_datadir}/ovn/scripts/ovs*
rm -rf $RPM_BUILD_ROOT%{_datadir}/ovn/bugtool-plugins
rm -f $RPM_BUILD_ROOT%{_libdir}/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/pkgconfig/*.pc
rm -f $RPM_BUILD_ROOT%{_includedir}/ovn/*
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/bash_completion.d/ovs-appctl-bashcomp.bash
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/bash_completion.d/ovs-vsctl-bashcomp.bash
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/openvswitch
rm -f $RPM_BUILD_ROOT%{_datadir}/ovn/scripts/ovn-bugtool*
rm -f $RPM_BUILD_ROOT/%{_bindir}/ovn-docker-overlay-driver \
        $RPM_BUILD_ROOT/%{_bindir}/ovn-docker-underlay-driver

%check
%if %{with check}
    touch resolv.conf
    export OVS_RESOLV_CONF=$(pwd)/resolv.conf
    if ! make check TESTSUITEFLAGS='%{_smp_mflags}'; then
        cat tests/testsuite.log
        if ! make check TESTSUITEFLAGS='--recheck'; then
            cat tests/testsuite.log
            # Presently a test case - "2796: ovn -- ovn-controller incremental processing"
            # is failing on aarch64 arch. Let's not exit for this arch
            # until we figure out why it is failing.
            # Test case 93: ovn.at:12105       ovn -- ACLs on Port Groups is failing
            # repeatedly on s390x. This needs to be investigated.
            %ifnarch aarch64
            %ifnarch ppc64le
            %ifnarch s390x
                exit 1
            %endif
            %endif
            %endif
        fi
    fi
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%pre central
if [ $1 -eq 1 ] ; then
    # Package install.
    /bin/systemctl status ovn-northd.service >/dev/null
    ovn_status=$?
    rpm -ql openvswitch-ovn-central > /dev/null
    if [[ "$?" = "0" && "$ovn_status" = "0" ]]; then
        # ovn-northd service is running which means old openvswitch-ovn-central
        # is already installed and it will be cleaned up. So start ovn-northd
        # service when posttrans central is called.
        touch %{_localstatedir}/lib/rpm-state/ovn-northd
    fi
fi

%pre host
if [ $1 -eq 1 ] ; then
    # Package install.
    /bin/systemctl status ovn-controller.service >/dev/null
    ovn_status=$?
    rpm -ql openvswitch-ovn-host > /dev/null
    if [[ "$?" = "0" && "$ovn_status" = "0" ]]; then
        # ovn-controller service is running which means old
        # openvswitch-ovn-host is installed and it will be cleaned up. So
        # start ovn-controller service when posttrans host is called.
        touch %{_localstatedir}/lib/rpm-state/ovn-controller
    fi
fi

%pre vtep
if [ $1 -eq 1 ] ; then
    # Package install.
    /bin/systemctl status ovn-controller-vtep.service >/dev/null
    ovn_status=$?
    rpm -ql openvswitch-ovn-vtep > /dev/null
    if [[ "$?" = "0" && "$ovn_status" = "0" ]]; then
        # ovn-controller-vtep service is running which means old
        # openvswitch-ovn-vtep is installed and it will be cleaned up. So
        # start ovn-controller-vtep service when posttrans host is called.
        touch %{_localstatedir}/lib/rpm-state/ovn-controller-vtep
    fi
fi

%preun central
%if 0%{?systemd_preun:1}
    %systemd_preun ovn-northd.service
%else
    if [ $1 -eq 0 ] ; then
        # Package removal, not upgrade
        /bin/systemctl --no-reload disable ovn-northd.service >/dev/null 2>&1 || :
        /bin/systemctl stop ovn-northd.service >/dev/null 2>&1 || :
    fi
%endif

%preun host
%if 0%{?systemd_preun:1}
    %systemd_preun ovn-controller.service
%else
    if [ $1 -eq 0 ] ; then
        # Package removal, not upgrade
        /bin/systemctl --no-reload disable ovn-controller.service >/dev/null 2>&1 || :
        /bin/systemctl stop ovn-controller.service >/dev/null 2>&1 || :
    fi
%endif

%preun vtep
%if 0%{?systemd_preun:1}
    %systemd_preun ovn-controller-vtep.service
%else
    if [ $1 -eq 0 ] ; then
        # Package removal, not upgrade
        /bin/systemctl --no-reload disable ovn-controller-vtep.service >/dev/null 2>&1 || :
        /bin/systemctl stop ovn-controller-vtep.service >/dev/null 2>&1 || :
    fi
%endif

%post
%if %{with libcapng}
if [ $1 -eq 1 ]; then
    sed -i 's:^#OVN_USER_ID=:OVN_USER_ID=:' %{_sysconfdir}/sysconfig/ovn
    sed -i 's:\(.*su\).*:\1 openvswitch openvswitch:' %{_sysconfdir}/logrotate.d/ovn
fi
%endif

%post central
%if 0%{?systemd_post:1}
    %systemd_post ovn-northd.service
%else
    # Package install, not upgrade
    if [ $1 -eq 1 ]; then
        /bin/systemctl daemon-reload >dev/null || :
    fi
%endif

%post host
%if 0%{?systemd_post:1}
    %systemd_post ovn-controller.service
%else
    # Package install, not upgrade
    if [ $1 -eq 1 ]; then
        /bin/systemctl daemon-reload >dev/null || :
    fi
%endif

%post vtep
%if 0%{?systemd_post:1}
    %systemd_post ovn-controller-vtep.service
%else
    # Package install, not upgrade
    if [ $1 -eq 1 ]; then
        /bin/systemctl daemon-reload >dev/null || :
    fi
%endif

%postun

%postun central
%if 0%{?systemd_postun_with_restart:1}
    %systemd_postun_with_restart ovn-northd.service
%else
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
    if [ "$1" -ge "1" ] ; then
    # Package upgrade, not uninstall
        /bin/systemctl try-restart ovn-northd.service >/dev/null 2>&1 || :
    fi
%endif

%postun host
%if 0%{?systemd_postun_with_restart:1}
    %systemd_postun_with_restart ovn-controller.service
%else
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
    if [ "$1" -ge "1" ] ; then
        # Package upgrade, not uninstall
        /bin/systemctl try-restart ovn-controller.service >/dev/null 2>&1 || :
    fi
%endif

%postun vtep
%if 0%{?systemd_postun_with_restart:1}
    %systemd_postun_with_restart ovn-controller-vtep.service
%else
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
    if [ "$1" -ge "1" ] ; then
        # Package upgrade, not uninstall
        /bin/systemctl try-restart ovn-controller-vtep.service >/dev/null 2>&1 || :
    fi
%endif

%posttrans central
if [ $1 -eq 1 ]; then
    # Package install, not upgrade
    if [ -e %{_localstatedir}/lib/rpm-state/ovn-northd ]; then
        rm %{_localstatedir}/lib/rpm-state/ovn-northd
        /bin/systemctl start ovn-northd.service >/dev/null 2>&1 || :
    fi
fi


%posttrans host
if [ $1 -eq 1 ]; then
    # Package install, not upgrade
    if [ -e %{_localstatedir}/lib/rpm-state/ovn-controller ]; then
        rm %{_localstatedir}/lib/rpm-state/ovn-controller
        /bin/systemctl start ovn-controller.service >/dev/null 2>&1 || :
    fi
fi

%posttrans vtep
if [ $1 -eq 1 ]; then
    # Package install, not upgrade
    if [ -e %{_localstatedir}/lib/rpm-state/ovn-controller-vtep ]; then
        rm %{_localstatedir}/lib/rpm-state/ovn-controller-vtep
        /bin/systemctl start ovn-controller-vtep.service >/dev/null 2>&1 || :
    fi
fi

%files
%{_bindir}/ovn-nbctl
%{_bindir}/ovn-sbctl
%{_bindir}/ovn-trace
%{_bindir}/ovn-detrace
%{_bindir}/ovn_detrace.py
%{_bindir}/ovn-appctl
%{_bindir}/ovn-ic-nbctl
%{_bindir}/ovn-ic-sbctl
%dir %{_datadir}/ovn/
%dir %{_datadir}/ovn/scripts/
%{_datadir}/ovn/scripts/ovn-ctl
%{_datadir}/ovn/scripts/ovn-lib
%{_datadir}/ovn/scripts/ovndb-servers.ocf
%{_mandir}/man8/ovn-ctl.8*
%{_mandir}/man8/ovn-appctl.8*
%{_mandir}/man8/ovn-nbctl.8*
%{_mandir}/man8/ovn-ic-nbctl.8*
%{_mandir}/man8/ovn-trace.8*
%{_mandir}/man1/ovn-detrace.1*
%{_mandir}/man7/ovn-architecture.7*
%{_mandir}/man8/ovn-sbctl.8*
%{_mandir}/man8/ovn-ic-sbctl.8*
%{_mandir}/man5/ovn-nb.5*
%{_mandir}/man5/ovn-ic-nb.5*
%{_mandir}/man5/ovn-sb.5*
%{_mandir}/man5/ovn-ic-sb.5*
%dir %{ovnlibdir}/ocf/resource.d/ovn/
%{ovnlibdir}/ocf/resource.d/ovn/ovndb-servers
%config(noreplace) %verify(not md5 size mtime) %{_sysconfdir}/logrotate.d/ovn
%config(noreplace) %verify(not md5 size mtime) %{_sysconfdir}/sysconfig/ovn

%files central
%{_bindir}/ovn-northd
%{_bindir}/ovn-ic
%{_mandir}/man8/ovn-northd.8*
%{_mandir}/man8/ovn-ic.8*
%{_datadir}/ovn/ovn-nb.ovsschema
%{_datadir}/ovn/ovn-ic-nb.ovsschema
%{_datadir}/ovn/ovn-sb.ovsschema
%{_datadir}/ovn/ovn-ic-sb.ovsschema
%{_unitdir}/ovn-northd.service
%{ovnlibdir}/firewalld/services/ovn-central-firewall-service.xml

%files host
%{_bindir}/ovn-controller
%{_mandir}/man8/ovn-controller.8*
%{_unitdir}/ovn-controller.service
%{ovnlibdir}/firewalld/services/ovn-host-firewall-service.xml

%files vtep
%{_bindir}/ovn-controller-vtep
%{_mandir}/man8/ovn-controller-vtep.8*
%{_unitdir}/ovn-controller-vtep.service

%changelog
* Wed Jul 12 2023 Xavier Simonart <xsimonar@redhat.com> - 22.12.0-108
- binding: fixed port claims as additional_chassis
[Upstream: 1ea5b0678de84bfd8842089b2ae5b963a4bfab93]

* Wed Jul 05 2023 Xavier Simonart <xsimonar@redhat.com> - 22.12.0-107
- tests: fixed "ovn-controller port security OF flows"
[Upstream: abe62ff428e98a499f2a4fa812d1163657f9f339]

* Wed Jul 05 2023 Ales Musil <amusil@redhat.com> - 22.12.0-106
- system-tests: Do not hardcode DP key for the flows
[Upstream: 7acca334e1d32e6a670228ab5d01058318bf764a]

* Wed Jul 05 2023 Xavier Simonart <xsimonar@redhat.com> - 22.12.0-105
- tests: fixed "MAC binding aging" and "IGMP external querier"
[Upstream: 2188f12baa79bef42ddff039a45fff03dd5318b9]

* Wed Jul 05 2023 Xavier Simonart <xsimonar@redhat.com> - 22.12.0-104
- tests: fixed "ACL Reject ping pong"
[Upstream: 3f934fef6d96cbcb6f588959e8f4e4decdab1995]

* Wed Jul 05 2023 Xavier Simonart <xsimonar@redhat.com> - 22.12.0-103
- tests: fixed "nb_cfg timestamp"
[Upstream: 52c4ab5be8b4e635b02008942dd76be5ad5686d5]

* Wed Jul 05 2023 Xavier Simonart <xsimonar@redhat.com> - 22.12.0-102
- tests: fixed "send gratuitous arp for nat ips in localnet"
[Upstream: cb4fa77b047ab546a7a6d40acd135c5a610d6313]

* Wed Jul 05 2023 Xavier Simonart <xsimonar@redhat.com> - 22.12.0-101
- tests: fixed "check meters update"
[Upstream: 4e0109bce5b5af989a7235f986a2704aaa85e681]

* Wed Jul 05 2023 Xavier Simonart <xsimonar@redhat.com> - 22.12.0-100
- tests: fixed "IPv6 periodic RA"
[Upstream: 5823aad6d2823a10574c288b07c9e552e91ca989]

* Wed Jul 05 2023 Xavier Simonart <xsimonar@redhat.com> - 22.12.0-99
- tests: decreased failure rate of "tug-of-war between two chassis for the same port"
[Upstream: b40e8db09f291b148eb1768ca4b723108d6c03c1]

* Wed Jul 05 2023 Xavier Simonart <xsimonar@redhat.com> - 22.12.0-98
- tests: fixed "send gratuitous ARP for NAT rules on HA distributed router"
[Upstream: 6c57972ee4038c0fe8271d791dbddeeb51393864]

* Wed Jul 05 2023 Xavier Simonart <xsimonar@redhat.com> - 22.12.0-97
- tests: fixed "dhcpv6 : 1 HV, 2 LS, 5 LSPs" and "external logical port"
[Upstream: 1af5a2ba376246639cefce47537fd6e767b29861]

* Wed Jul 05 2023 Xavier Simonart <xsimonar@redhat.com> - 22.12.0-96
- tests: fixed "policy-based routing" and "route tables IPv6 -- overlapping subnets"
[Upstream: 662b8f3fbc4c960a8a6498b3ab632396cfdef907]

* Fri Jun 30 2023 Han Zhou <hzhou@ovn.org> - 22.12.0-95
- mirror.c: Fix ovn-controller crash when mirror port is deleted from ovs.
[Upstream: 0436c363d4174f0333abce8866b5439d3372d1b1]

* Fri Jun 16 2023 Xavier Simonart <xsimonar@redhat.com> - 22.12.0-94
- tests: Fix Flaky system-tests "omit connection tracking ..."
[Upstream: 01b51893e0618b62998190eb59870c43b455f400]

* Fri Jun 16 2023 venu iyer <venugopali@nvidia.com> - 22.12.0-93
- northd: bypass connection tracking for stateless flows when there are LB flows present (#2215137)
[Upstream: 6be84b57732d1756f5970e267581e691543be936]

* Fri Jun 09 2023 Igor Zhukov <ivzhukov@sbercloud.ru> - 22.12.0-92
- call ovsrcu_exit() before exit in ovn-northd and ovn-controller to make valgrind happy
[Upstream: baab5118b57a532683ccc3b3b67b3fc5135d4d76]

* Thu Jun 08 2023 Dumitru Ceara <dceara@redhat.com> - 22.12.0-91
- controller: Turn OFTABLE_OUTPUT_INIT into an alias.
[Upstream: d9986501e01bab2307f9cb6b7f6db2bb349ea71c]

* Thu Jun 08 2023 Ihar Hrachyshka <ihrachys@redhat.com> - 22.12.0-90
- Implement MTU Path Discovery for multichassis ports
[Upstream: 9498b5472b159080954d3922cbc6ab42a6d5b9c0]

* Thu Jun 08 2023 Ihar Hrachyshka <ihrachys@redhat.com> - 22.12.0-89
- Add new egress tables to accommodate for too-big packets handling
[Upstream: b3ec6c4bc5c30f8f6070dabe6270347fc764e35c]

* Thu Jun 08 2023 Ihar Hrachyshka <ihrachys@redhat.com> - 22.12.0-88
- if-status: track interfaces for additional chassis
[Upstream: 8e7ab61a97a681a94c0f11f8c1e2bfc1b033af62]

* Thu Jun 08 2023 Ihar Hrachyshka <ihrachys@redhat.com> - 22.12.0-87
- Track interface MTU in if-status-mgr
[Upstream: 1d07d345000707d787d640c8d199c933ac51f4e7]

* Thu Jun 08 2023 Ihar Hrachyshka <ihrachys@redhat.com> - 22.12.0-86
- Track ip version of tunnel in chassis_tunnel struct
[Upstream: 558539edead624d1e29b5c9760f76efc93ec7a9b]

* Thu Jun 08 2023 Ales Musil <amusil@redhat.com> - 22.12.0-85
- northd: Add logical flow to skip GARP with LLA (#2211240)
[Upstream: ce6b553a48aef1c6da9e84ee3d0bcdea88abed5b]

* Thu Jun 08 2023 Vladislav Odintsov <odivlad@gmail.com> - 22.12.0-84
- northd: match only on supported protocols to handle_svc_check (#1913162)
[Upstream: 4b6a357fbd573a311467164b489b1993c61af234]

* Thu Jun 08 2023 Xavier Simonart <xsimonar@redhat.com> - 22.12.0-83
- tests: Fixed "nested containers" test
[Upstream: a20d143e23ee4912d47eddf1d438e0f41ebd5a6e]

* Thu Jun 08 2023 Xavier Simonart <xsimonar@redhat.com> - 22.12.0-82
- tests: fix flaky Multiple OVS interfaces bound to same logical ports
[Upstream: 6eb9eb0d0a646a3f8b9562420d0494b5dc7f5fe9]

* Thu Jun 08 2023 Ales Musil <amusil@redhat.com> - 22.12.0-81
- system-tests: Prevent flakiness in ovn mirroring
[Upstream: 1ae331136b7f6bb90e96bb66d789d1a90d8be956]

* Thu Jun 08 2023 Ales Musil <amusil@redhat.com> - 22.12.0-80
- northd: Fix address set incremental processing (#2196885)
[Upstream: 2792040af60a02a2b19bfd0c2db0abc67eff9e69]

* Tue May 30 2023 Brian Haley <haleyb.dev@gmail.com> - 22.12.0-79
- controller: Ignore DNS queries with RRs
[Upstream: 0b0dc4a36d18a2edec59b3c0a3c6af0687c121e5]

* Tue May 30 2023 Ales Musil <amusil@redhat.com> - 22.12.0-78
- ci: ovn-kubernetes: Align the timeouts with u/s ovnk
[Upstream: 743d95c3072238261b810cf06e92033b385d3d96]

* Tue May 30 2023 Dumitru Ceara <dceara@redhat.com> - 22.12.0-77
- controller: Handle OpenFlow errors. (#2134880)
[Upstream: 756ae953bce44a6a2cbea7d98cecb8650dc0966b]

* Tue May 30 2023 Vladislav Odintsov <odivlad@gmail.com> - 22.12.0-76
- controller: fix typo in comments
[Upstream: c3a2c1f2ae43402c74edaf3af7793cd91f959d02]

* Tue May 30 2023 Vladislav Odintsov <odivlad@gmail.com> - 22.12.0-75
- northd: build vtep hairpin lflows only for lswitches with vtep lports
[Upstream: 94e6720eb057a1557d80f145e4a698aebe2103d9]

* Tue May 30 2023 Vladislav Odintsov <odivlad@gmail.com> - 22.12.0-74
- northd: fix ls_in_hairpin l3dgw flow generation
[Upstream: 15d7735b60010df8a1f43abd9adc0e4b59c18539]

* Fri May 26 2023 Han Zhou <hzhou@ovn.org> - 22.12.0-73
- ovn-controller.c: Fix assertion failure during address set update.
[Upstream: 1f9415e59cdb95fcd31f2e4259b5a2a50ec4b71b]

* Fri May 19 2023 Mark Michelson <mmichels@redhat.com> - 22.12.0-72
- Pass localnet traffic through CT when a LB is configured. (#2164652)
[Upstream: f827ad3daf263706b7ecace32b4076be7fa4b080]

* Fri May 19 2023 Mark Michelson <mmichels@redhat.com> - 22.12.0-71
- tests: Use stricter IP match for FORMAT_CT.
[Upstream: 21305a624541b749d4eb98007b139ca86651f673]

* Wed May 17 2023 Ales Musil <amusil@redhat.com> - 22.12.0-70
- tests: Fix flakiness of policy based routing on slower systems
[Upstream: 8ea170b8d2613817b021a856645b52f29ebb55e3]

* Wed May 17 2023 Vladislav Odintsov <odivlad@gmail.com> - 22.12.0-69
- ovn-controller docs: fix typo in ovn-monitor-all description
[Upstream: 15af98efbe2600f65d486caec3bb03153bf3f8c2]

* Wed May 10 2023 Ales Musil <amusil@redhat.com> - 22.12.0-68
- system-tests: Replace use of ADD_INT with ADD_VETH
[Upstream: 9642f275a756a0af121a8f923c695624bcefeff6]

* Wed May 10 2023 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.12.0-67
- controller: fix possible unaligned accesses in DHCPv6 code
[Upstream: f94919faf39c390804c605bfb2ccbf3982f8f233]

* Tue May 09 2023 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.12.0-66
- mirror: fix ovn mirror support with IPv6 (#2168119)
[Upstream: 66aeaf50d273d5fe03ccf99e8163157c6a200ba2]

* Mon May 08 2023 Xavier Simonart <xsimonar@redhat.com> - 22.12.0-65
- ovn-controller: fixed port not always set down when unbinding interface (#2150905)
[Upstream: 69febf87a8936fb9c29b2be2ce9c98df540cf8b7]

* Mon May 08 2023 Xavier Simonart <xsimonar@redhat.com> - 22.12.0-64
- ovn-controller: fixed ovn-installed not always properly added or removed.
[Upstream: f30972aec88e1fe346492429b6e6b9a6df37ecda]

* Mon May 08 2023 Wei Li <liw@yusur.tech> - 22.12.0-63
- documentation: packets that arrive from other chassis resubmit to table 38
[Upstream: e10ecd30e1898d77829c98f589c300d7dbaba319]

* Mon May 08 2023 Tao Liu <taoliu828@163.com> - 22.12.0-62
- northd: fix use-after-free after lrp destroyed
[Upstream: a52cb793890af9d58f8a0da62bb761dbb053fa4c]

* Mon May 08 2023 Ihar Hrachyshka <ihrachys@redhat.com> - 22.12.0-61
- docs: document that vxlan is supported for encap type
[Upstream: e93f97927257419117a597f330b8f2322b3b99c0]

* Mon May 08 2023 Xavier Simonart <xsimonar@redhat.com> - 22.12.0-60
- tests: Fixed flaky lr multiple gw ports
[Upstream: 95ec62f9e694e58658790c11bfbe3fd36b293c46]

* Mon May 08 2023 Xavier Simonart <xsimonar@redhat.com> - 22.12.0-59
- Fix test "load-balancing"
[Upstream: ba676bbc5fc40e379bdc4f7657a0ce3cc4b68d1e]

* Fri May 05 2023 Dumitru Ceara <dceara@redhat.com> - 22.12.0-58
- tests: Retry inject-pkt in case ovn-controller is still busy.
[Upstream: 39930ffb3c79b6babb5476a3d49355e1d614fe4e]

* Tue May 02 2023 wangchuanlei <wangchuanlei@inspur.com> - 22.12.0-57
- pinctrl: fix restart of controller when bfd min_tx is too low.
[Upstream: d5a552a751456181f2faff6138c4f5af47cd89fd]

* Tue May 02 2023 Ales Musil <amusil@redhat.com> - 22.12.0-56
- ovn-nbctl: Fix unhandled NULL return from normalize_prefix_str
[Upstream: 23abfa1aa2adb85f78b459054e6b241d0571cae9]

* Mon May 01 2023 Xavier Simonart <xsimonar@redhat.com> - 22.12.0-55
- tests: decrease risk of flaky failures of ovn -- CoPP system test
[Upstream: af43d9e1e5f23aee6d826af88b6b3539003a5f7c]

* Mon May 01 2023 Xavier Simonart <xsimonar@redhat.com> - 22.12.0-54
- tests: check arguments count of OVS_WAIT_UNTIL
[Upstream: 235f4676311975be903b7ad1481379142a45d971]

* Mon May 01 2023 Xavier Simonart <xsimonar@redhat.com> - 22.12.0-53
- tests: Fixed wrong usage of OVS_WAIT_UNTIL
[Upstream: 97d2b31732c8c1f3e706f314fd310c8ce4637656]

* Mon May 01 2023 Xavier Simonart <xsimonar@redhat.com> - 22.12.0-52
- tests: Fixed "1 LR with HA distributed router gateway port"
[Upstream: 13efc90e5506ab7dcba53eefd7bf9e8b2921d228]

* Fri Apr 21 2023 Mark Michelson <mmichels@redhat.com> - 22.12.0-51
- tests: Skip "daemon ssl files change" when SSL is disabled.
[Upstream: b272e8b1c5898e1f228f52a83dba09bb25032b3c]

* Wed Apr 19 2023 Ihar Hrachyshka <ihrachys@redhat.com> - 22.12.0-50
- Omit ACLs for nd || nd_ra || nd_rs || mldv1 || mldv2 (#2149731)
[Upstream: 21d849748f27f78837de577ee79a004626732bb3]

* Wed Apr 19 2023 Ihar Hrachyshka <ihrachys@redhat.com> - 22.12.0-49
- tests: define fmt_pkt function to construct packets with scapy
[Upstream: ca035adf8d785d89bfa181731f934ca2ae1d8ad5]

* Wed Apr 19 2023 Ales Musil <amusil@redhat.com> - 22.12.0-48
- controller: Prevent race in tunnel cleanup
[Upstream: 4f60322b033301d0dfac4b716a7a420cec6c56b0]

* Wed Apr 19 2023 Dumitru Ceara <dceara@redhat.com> - 22.12.0-47
- nbctl: Display "apply-after-lb" information when listing ACLs.
[Upstream: c1417b6a7e02017e0f4103862d8fa26b18f9ee71]

* Fri Apr 14 2023 Han Zhou <hzhou@ovn.org> - 22.12.0-46
- northd.c: Avoid sending ICMP time exceeded for multicast packets.
[Upstream: f1d9ed6061d96fea0f0042354c2d765ff6a94d7b]

* Fri Apr 14 2023 Han Zhou <hzhou@ovn.org> - 22.12.0-45
- northd.c: TTL discard flow should support for both ipv4 and ipv6.
[Upstream: 37e6917bd29badf10b99a5e0d00f70d4a0cd8384]

* Tue Apr 11 2023 Ales Musil <amusil@redhat.com> - 22.12.0-44
- northd: Update the is_stateless helper for router nat
[Upstream: bf70009facad7dfb1ead0e89efa0c5e2255f671d]

* Tue Apr 11 2023 Eelco Chaudron <echaudro@redhat.com> - 22.12.0-43
- ci: Add arping package to run floating IP tests.
[Upstream: 9baf13907ab041e607f1abd749eed113f7515331]

* Tue Apr 11 2023 Ales Musil <amusil@redhat.com> - 22.12.0-42
- controller: Clear tunnels from old integration bridge (#2173635)
[Upstream: c259c5d8cf46b50d9585fcac0cb9345e7deece6f]

* Thu Apr 06 2023 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.12.0-41
- northd: take into account qos_min_rate in port_has_qos_params
[Upstream: 3e783aab3ad49fb877f3339668f6be6d289535f9]

* Mon Apr 03 2023 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.12.0-40
- controller: lflow: do not use tcp as default IP protocol for ct_snat_to_vip action (#2157846)
[Upstream: 7cedd7714e449b26539f027cd339fd3b7de99bcb]

* Fri Mar 31 2023 Ales Musil <amusil@redhat.com> - 22.12.0-39
- northd: Drop packets for LBs with no backends (#2177173)
[Upstream: f898f470a0f9280d8e67c541ea38344a3ddab192]

* Fri Mar 31 2023 Ales Musil <amusil@redhat.com> - 22.12.0-38
- northd: Make the enclose handling less error prone
[Upstream: ce7f482b485a1a957cf28c970942908bd62952ac]

* Thu Mar 30 2023 Ales Musil <amusil@redhat.com> - 22.12.0-37
- system-tests: Reduce flakiness of netcat UDP clients
[Upstream: 7e36a95c938b4301ed3c424da7bfa812f26ad895]

* Thu Mar 30 2023 Dumitru Ceara <dceara@redhat.com> - 22.12.0-36
- lb: Allow IPv6 template LBs to use explicit backends.
[Upstream: b449a760eed1a67888a545f1099b08e5e7a5bbb5]

* Tue Mar 28 2023 Xavier Simonart <xsimonar@redhat.com> - 22.12.0-35
- northd: prevents sending packet to conntrack for router ports (#2062431)
[Upstream: fa5ac8e541a35612a4953ad1944b6c46dd5a540d]

* Thu Mar 16 2023 Dumitru Ceara <dceara@redhat.com> - 22.12.0-34
- northd: Ignore remote chassis when computing the supported feature set.
[Upstream: 31ffefe9f6cc65192a8158adc41ad7adb02f634b]

* Thu Mar 09 2023 Ales Musil <amusil@redhat.com> - 22.12.0-33
- northd: Fix missig "); " from LB flows
[Upstream: cf205ca0e52c425a14f49145fa74b3fe293b547e]

* Thu Mar 02 2023 Ilya Maximets <i.maximets@ovn.org> - 22.12.0-32
- ovn-util: Remove unused ovn_parse_internal_version_minor.
[Upstream: 5b9e7a70386ee9863469fbf2ce4b9a4d922716d8]

* Thu Mar 02 2023 Felix Hüttner <felix.huettner@mail.schwarz> - 22.12.0-31
- northd: fix comments on functions
[Upstream: 79dca2c4d0f3550757b6e3bb0813703348dab541]

* Thu Mar 02 2023 Ales Musil <amusil@redhat.com> - 22.12.0-30
- system-tests: Reduce flakiness of ACL reject tests
[Upstream: b3196d1b140c98b409086ca72880a76da96c6c62]

* Thu Mar 02 2023 Ales Musil <amusil@redhat.com> - 22.12.0-29
- dbctl: Fix a couple of memory leaks
[Upstream: 2733558a2e76ad6db3fc639f1bd8235d6382248b]

* Thu Mar 02 2023 Dumitru Ceara <dceara@redhat.com> - 22.12.0-28
- ci: ovn-kubernetes: Bump libovsdb to a6a173993830.
[Upstream: 81ae7831f8d64a114a1be265782b6aa9ad0c52db]

* Wed Mar 01 2023 Xavier Simonart <xsimonar@redhat.com> - 22.12.0-27
- tests: Fixed some tests failing on (very) slow systems
[Upstream: 2bd8697b25ac4342af33985899248248557c5481]

* Mon Feb 27 2023 Ales Musil <amusil@redhat.com> - 22.12.0-26
- tests: Decrease the number of zones and switches for interconnection
[Upstream: 2a24ebc3064959c57ded1060a6a31be5397382b3]

* Thu Feb 16 2023 Dumitru Ceara <dceara@redhat.com> - 22.12.0-25
- lb: northd: Properly format IPv6 SB load balancer VIPs.
[Upstream: 7053ae61267ebcb282d5ef18b5bd8f2f6c6c37e0]

* Wed Feb 15 2023 Ales Musil <amusil@redhat.com> - 22.12.0-24
- system-test: Use OVS_WAIT_UNTIL for tcpdump start instead fo sleep
[Upstream: d5273f929513458a569cdfb297bffd9922d44c01]

* Wed Feb 15 2023 Ihar Hrachyshka <ihrachys@redhat.com> - 22.12.0-23
- docs: fix the max number of ports per network for vxlan
[Upstream: 4dfa4ba431ab634b6068f27e886a4d403d589c87]

* Wed Feb 15 2023 Ales Musil <amusil@redhat.com> - 22.12.0-22
- ovn-nbctl: Fix documentation typo (#2168009)
[Upstream: 0c44d7dbf4a013f08c79d5818e89a8f55ecd09e0]

* Wed Feb 15 2023 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.12.0-21
- northd: do not create flows for reserved multicast IPv6 groups (#2154930)
[Upstream: 61e030ed59c2d2a1029866dce6769428e0abbc0c]

* Thu Feb 02 2023 Han Zhou <hzhou@ovn.org> - 22.12.0-20
- northd.c: Validate port type to avoid unexpected behavior.
[Upstream: b67009fdb6312e95367183c65b439fd3b7a288bf]

* Tue Jan 31 2023 Surya Seetharaman <suryaseetharaman.9@gmail.com> - 22.12.0-19
- Add the metalLB install flag for CI actions
[Upstream: 65990b8398e8e7ff29c6d7e9903fd0cf7ef64965]

* Mon Jan 23 2023 Ales Musil <amusil@redhat.com> - 22.12.0-18
- ovn-trace: Use the original ovnact for execute_load
[Upstream: 4c78bef966927f4083b601a6a4f5fc76a839fd1a]

* Mon Jan 23 2023 Dumitru Ceara <dceara@redhat.com> - 22.12.0-17
- northd: Add logical flows to allow rpl/rel traffic in acl_after_lb stage. (#1947807)
[Upstream: d6914efd53ac28a6e3da6e65f9e026674f05dc4c]

* Fri Jan 20 2023 Mark Michelson <mmichels@redhat.com> - 22.12.0-16
- ovn-controller: Fix initial requested SNAT zone assignment. (#2160403)
[Upstream: 17f1e9e0148e298b6ec525d5d6b149082a864dca]

* Thu Jan 19 2023 Han Zhou <hzhou@ovn.org> - 22.12.0-15
- northd: Drop packets destined to router owned NAT IP for DGP.
[Upstream: 481f25b784896eec07fedc77631992a009bcdada]

* Thu Jan 19 2023 Ales Musil <amusil@redhat.com> - 22.12.0-14
- northd: Add flag for CT related (#2126083)
[Upstream: 2619f6a27aca2a5925e25297f75e6a925cf1eb6a]

* Wed Jan 18 2023 Xavier Simonart <xsimonar@redhat.com> - 22.12.0-13
- tests: Fixed load balancing system-tests
[Upstream: 1791a107debbaa474669a794b4d2a6dff4cb1dcb]

* Wed Jan 18 2023 Xavier Simonart <xsimonar@redhat.com> - 22.12.0-12
- tests: Fixed flaky ACL fair Meters
[Upstream: f9fb0bb4de4e7cb0a02fcb0794e226e6af8e8f5c]

* Wed Jan 18 2023 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.12.0-11
- northd: move hairpin stages before acl_after_lb (#2103086)
[Upstream: 3723a6d6e39dcffc502e094ccc10a8d638fa5efa]

* Tue Jan 17 2023 Xavier Simonart <xsimonar@redhat.com> - 22.12.0-10
- controller: Fix missing first ping from pod to external (#2129283)
[Upstream: 7109f02b78f5087b5bae2885f153378e627d90f7]

* Mon Jan 16 2023 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.12.0-9
- controller: use packet proto for hairpin traffic learned action if not specified (#2157846)
[Upstream: 588291528fc0568e7da402c05b596c6c855d2c5f]

* Fri Jan 13 2023 Dumitru Ceara <dceara@redhat.com> - 22.12.0-8
- .ci: ovn-kubernetes: Add a "prepare" stage to allow for custom actions.
[Upstream: 29fb21e6ec0a1203e3f5b2bfff4c3ccea8df4d37]

* Wed Jan 11 2023 Han Zhou <hzhou@ovn.org> - 22.12.0-7
- build-aux/sodepends.py: Fix flake8 error.
[Upstream: 1fd28ef34bef9b19ca350f15bd03e10265a911dc]

* Wed Jan 11 2023 Han Zhou <hzhou@ovn.org> - 22.12.0-6
- build-aux/sodepends.py: Fix broken build when manpage changes.
[Upstream: 79edad8a1e547f4120ea3d20f08aafe1e40a6f65]

* Tue Jan 10 2023 Dumitru Ceara <dceara@redhat.com> - 22.12.0-5
- ovn-ic: Only monitor useful tables and columns.
[Upstream: fdad33f2348f34b5fb886a5a3143d91f44021811]

* Fri Dec 16 2022 Mark Michelson <mmichels@redhat.com> - 22.12.0-4
- Prepare for 22.12.1.
[Upstream: 78af8b76ab30ad3e704211256c313dec67f63cb8]

